@@ -16,12 +16,9 @@ Comics::Fetcher::GoComics -- Fetcher for GoComics.
   package Comics::Plugin::Garfield;
   use parent qw(Comics::Fetcher::GoComics);
 
-  sub register {
-      shift->SUPER::register
-	( { name    => "Garfield",
-	    url     => "http://www.comics.com/garfield",
-	  } );
-  }
+  our $name    = "Garfield";
+  our $url     = "https://www.comics.com/garfield";
+
   # Return the package name.
   __PACKAGE__;
 
@@ -54,10 +51,11 @@ Fetcher specific arguments:
 
 =cut
 
-our $VERSION = "1.02";
+our $VERSION = "1.04";
 
 # Page contents changed, january 10, 2017.
 # Page contents changed, april 5, 2018.
+# Page contents changed, april 1, 2025.
 
 sub register {
     my ( $pkg, $init ) = @_;
@@ -66,18 +64,18 @@ sub register {
     my $self = $pkg->SUPER::register($init);
 
     if ( ! $self->{url} && $self->{tag} ) {
-	$self->{url} = "http://www.gocomics.com/" . $self->{tag} . "/";
+	$self->{url} = "https?://www.gocomics.com/" . $self->{tag} . "/";
     }
 
     # Add the standard pattern for GoComics comics.
     $self->{patterns} =
       [
-       qr{ href="(?<url>.*?)">Comics</a>
-         }x,
-       qr{ <meta \s+ property="og:image" \s+
-	   content="(?<url>https?://assets.amuniversal.com/
-	   (?<image>[0-9a-f]+))" \s+
-           />
+       qr{ <link \s+
+	   rel="preload" \s+
+	   as="image" \s+
+	   imageSrcSet="
+	     (?<url>https://featureassets.gocomics.com/assets/
+	       (?<image>[0-9a-f]+))
          }x,
        ];
 
