@@ -7,10 +7,10 @@ package Comics::Plugin::Ben;
 
 use parent qw(Comics::Fetcher::GoComics );
 
-our $VERSION = "1.00";
+our $VERSION = "1.01";
 
 our $name    = "Ben";
-our $url     = "http://www.gocomics.com/ben/";
+our $url     = "https://www.gocomics.com/ben/";
 
 # Important: Return the package name!
 __PACKAGE__;
