@@ -10,7 +10,7 @@ use parent qw(Comics::Fetcher::GoComics);
 our $VERSION = "1.00";
 
 our $name = "Calvin and Hobbes";
-our $url  = "http://www.comics.com/calvinandhobbes";
+our $url  = "https://www.gocomics.com/calvinandhobbes";
 
 # Important: Return the package name!
 __PACKAGE__;
