@@ -7,10 +7,10 @@ package Comics::Plugin::EEK;
 
 use parent qw(Comics::Fetcher::GoComics);
 
-our $VERSION = "1.02";
+our $VERSION = "1.03";
 
 our $name    = "EEK!";
-our $url     = "http://www.gocomics.com/eek/";
+our $url     = "https://www.gocomics.com/eek";
 
 # Important: Return the package name!
 __PACKAGE__;
