@@ -7,10 +7,11 @@ package Comics::Plugin::MrLovenstein;
 
 use parent qw(Comics::Fetcher::Single);
 
-our $VERSION = "1.00";
+our $VERSION = "1.01";
 
 our $name    = "Mr. Lovenstein";
-our $url     = "http://www.mrlovenstein.com/";
+our $url     = "https://mrlovenstein.com/";
+our $disabled = 1;		# out of reach
 
 our $pattern =
   qr{ <img \s+
