@@ -7,7 +7,7 @@ package Comics::Plugin::PoorlyDrawnLines;
 
 use parent qw(Comics::Fetcher::Single);
 
-our $VERSION = "1.06";
+our $VERSION = "1.07";
 
 our $name    = "Poorly Drawn Lines";
 our $url     = "https://www.poorlydrawnlines.com/";
@@ -16,8 +16,8 @@ our $pattern =
   qr{ <div \s+ class="wp-block-image[^"]*"> \s*
       <figure \s+ class=".*?">
       <a \s* href=".*?">
-      <img \s+ (?: (?:loading|width|height) = "[^"]+" \s+ )*
-       src="(?<url>https://secureservercdn.net/192.169.220.85/hk8.901.myftpupload.com/wp-content/uploads/
+      <img \s+ (?: (?:loading|width|height|decoding) = "[^"]+" \s+ )*
+       src="(?<url>https://poorlydrawnlines.com/wp-content/uploads/
 	      \d+/\d+/
 	      (?<image>.+?\.\w+))"
     }x;
