@@ -7,7 +7,7 @@ package Comics::Plugin::Speedbump;
 
 use parent qw(Comics::Fetcher::Single);
 
-our $VERSION = "1.01";
+our $VERSION = "1.02";
 
 our $name    = "Speedbump";
 our $url     = "https://www.speedbump.com/";
@@ -17,8 +17,8 @@ our $pattern =
       <a \s+ href="/" >
       <img \s+
        src="?
-           (?<url>/+static.*?.squarespace.com/static/
-            .*?/t/.*?/(?<image>.*?)/\?format=\d+w)
+           (?<url>//images.squarespace-cdn.com/content/v1/
+            .*?/.*?/(?<image>.*?)\?format=\d+w)
            "?
     }x;
 
