@@ -7,14 +7,10 @@ package Comics::Plugin::WorkingDaze;
 
 use parent qw(Comics::Fetcher::GoComics);
 
-our $VERSION = "0.02";
+our $VERSION = "1.02";
 
-sub register {
-    shift->SUPER::register
-      ( { name    => "Working Daze",
-	  url     => "https://www.gocomics.com/working_daze",
-	} );
-}
+our $name    = "Working Daze";
+our $url     = "https://www.gocomics.com/working-daze";
 
 # Important: Return the package name!
 __PACKAGE__;
